@@ -98,17 +98,18 @@ class MigrationDB:
         self.__logger.debug(f'Получен объект {config}')
         self.__logger.debug(f'Получен объект {self.__logger}')
 
-        self.__connection = Connection(host=config.DB['host'], user=config.DB['migration']['user'],
-                                       password=config.DB['migration']['password'], port=config.DB['port'],
-                                       db=config.DB['DB_name'], autocommit=True)
+        self.__db_user = config.migration['user']
+        self.__db_password = config.migration['password']
+        self.__db_name = config.migration['DB_name']
+
+        self.__connection = Connection(host=config.migration['host'], user=self.__db_user,
+                                       password=self.__db_password, port=config.migration['port'],
+                                       db=self.__db_name, autocommit=True)
         self.__logger.debug(f'Получен объект {self.__connection}')
 
         self.__logger.debug(f'Полный путь до модуля: {_path_to_module}')
 
-        self.__db_user = config.DB['migration']['user']
-        self.__db_password = config.DB['migration']['password']
-        self.__db_name = config.DB['DB_name']
-        self.__rollback_on_error = config.DB['migration']['rollback_on_error']
+        self.__rollback_on_error = config.migration['rollback_on_error']
 
         self.__path_scripts = getenv('MIGRATION_SCRIPTS')
         if not self.__path_scripts:
